@@ -39,17 +39,14 @@ static void Tcc4tclCCommandDeleteProc (ClientData cdata) {
 	ts = (struct TclTCCState *) cdata;
 	s = ts->s;
 
-	/* We can delete the compiler if the output was not to memory */
-	if (s->output_type != TCC_OUTPUT_MEMORY) {
-		tcc_delete(s);
-		ts->s = NULL;
-	}
+	ts->s = NULL;
 
 	ckfree((void *) ts);
 }
 
 static int Tcc4tclHandleCmd ( ClientData cdata, Tcl_Interp *interp, int objc, Tcl_Obj * CONST objv[]){
-	unsigned long val;
+	Tcl_WideInt val;
+	Tcl_Obj *val_o;
 	void *val_p;
 	int index;
 	int res;
@@ -68,6 +65,7 @@ static int Tcc4tclHandleCmd ( ClientData cdata, Tcl_Interp *interp, int objc, Tc
 		TCC4TCL_DEFINE, TCC4TCL_GET_SYMBOL, TCC4TCL_OUTPUT_FILE, TCC4TCL_UNDEFINE
 	};
 	char *str;
+	int rv;
 
 	ts = (struct TclTCCState *) cdata;
 	s = ts->s;
@@ -123,7 +121,16 @@ static int Tcc4tclHandleCmd ( ClientData cdata, Tcl_Interp *interp, int objc, Tc
                 return TCL_ERROR;
             }
 
-            Tcl_GetLongFromObj(interp, objv[3], &val);
+            rv = Tcl_ExprObj(interp, Tcl_ObjPrintf("wide(%s)", Tcl_GetString(objv[3])), &val_o);
+            if (rv != TCL_OK) {
+                return TCL_ERROR;
+            }
+
+            rv = Tcl_GetWideIntFromObj(interp, val_o, &val);
+            if (rv != TCL_OK) {
+                return TCL_ERROR;
+            }
+
             val_p = (void *) val;
 
             tcc_add_symbol(s,Tcl_GetString(objv[2]), val_p); 
